采购人名称：2020年政法三级网设备维保服务项目
采购人地址：邢台市新西街166号
采购人联系人、联系方式： 赵冀勇 0319-3270085
采购代理机构全称：邢台市政府采购中心
采购代理机构地址：邢台市泉北西大街2868号
采购代理机构联系人、联系方式：梁立波0319-2681219
采购内容：2020年政法三级网设备维保服务项目
采购方式：竞争性磋商
项目实施地点：详见招标文件。
采购公告日期：2020-04-03
定标日期：2020-04-20
开评标地点：网上开标,第八评标室评标
分包编号：XTSGP2020-009/01
分包名称：2020年政法三级网设备维保服务项目
中标供应商名称:1 北京润博星原科技发展有限公司 中标供应商地址： 中标供应商组织机构代码： 中标金额：1068000.00元 中标数量： 单价： 优惠折扣率：
评标委员会成员名单：李永军（磋商小组组长）赵冀勇（采购单位代表） 王金龙
采购代理机构受理质疑电话：0319-2681219
本次公告发布媒体：河北省政府采购网、邢台市公共资源交易中心网、招采进宝河北专区
备注：